@@ -29,7 +29,7 @@ impl<T> DerefMut for Base64<T> {
     }
 }
 
-impl<T: Send + Sync> Type for Base64<T> {
+impl<T: AsRef<[u8]> + Send + Sync> Type for Base64<T> {
     const IS_REQUIRED: bool = true;
 
     type RawValueType = Self;
@@ -53,6 +53,10 @@ impl<T: Send + Sync> Type for Base64<T> {
     ) -> Box<dyn Iterator<Item = &'a Self::RawElementValueType> + 'a> {
         Box::new(self.as_raw_value().into_iter())
     }
+
+    fn is_empty(&self) -> bool {
+        self.0.as_ref().is_empty()
+    }
 }
 
 impl ParseFromJSON for Base64<Vec<u8>> {
